# MQtfy - Ntfy Mqtt Gateway
Send MQTT Messages to send ntfy Notifications and subscribe to ntfy to send them to mqtt

### Installation


```bash
$ cp config.yaml.example config.yaml # update the yaml to fit your needs
$ pip install mqtfy
```
